import flet as ft
from requests.board_games import get_sections, get_games, get_user_discounts


def root(page: ft.Page):
    user_id = page.client_storage.get("user_id");

    discounts = []

    if user_id is not None:
        discounts = get_user_discounts(user_id)

    def update_games(section):
        current_section.value = section
        games = get_games(None if section == "Все" else section)
        grid.controls.clear()
        for game in games:
            for d in discounts:
                if d.game_id == game.board_game_id:
                    game.discount = d.discount

            grid.controls.append(
                ft.Column([
                    ft.Text(str(game)),
                    ft.Row([
                        ft.IconButton(icon=ft.icons.SHOPPING_CART),
                        ft.IconButton(icon=ft.icons.FAVORITE),
                    ]),
                ])
            )
        page.update()

    sections = [*get_sections(), "Все"]

    sections_buttons = [ft.Button(section, on_click=lambda e, s=section: update_games(s)) for section in sections]

    games = get_games()

    current_section = ft.Ref[str]()



    grid = ft.GridView(
        expand=1,
        runs_count=5,
        max_extent=200,
        child_aspect_ratio=1.0,
        spacing=5,
        run_spacing=5,
    )

    for game in games:
        for d in discounts:
            if d.game_id == game.board_game_id:
                game.discount = d.discount

        grid.controls.append(
            ft.Column([
                ft.Text(str(game)),
                ft.Row([
                    ft.IconButton(
                        icon=ft.Icons.SHOPPING_CART
                    ),
                    ft.IconButton(
                        icon=ft.Icons.FAVORITE
                    )
                ])
            ])
        )

    def go_to_login():
        page.route = "/login"
        page.update()

    def go_to_register():
        page.route = "/register"
        page.update()

    def go_to_profile():
        page.route = "/profile"
        page.update()

    def logout():
        page.client_storage.remove("user_id")
        page.clean()
        root(page)
        page.update()

    user_id = page.client_storage.get("user_id")

    page.add(
        ft.Row(
            [
                ft.Text(
                    "Весёлые кубики",
                    color="#59799f",
                    size=24,
                    weight=ft.FontWeight.BOLD,
                ),
                ft.Row([
                    ft.Button(
                        text="Вход",
                        on_click=lambda e: go_to_login(),
                    ),
                    ft.Button(
                        text="Регистрация",
                        on_click=lambda e: go_to_register(),
                    ),
                ]) if user_id is None else ft.Row([
                    ft.Button(
                        "Профиль",
                        on_click=lambda e: go_to_profile()
                    ),
                    ft.Button(
                        text="Выйти",
                        on_click=lambda e: logout(),
                    )
                ])
            ],
            alignment=ft.MainAxisAlignment.SPACE_BETWEEN,  # Adjust alignment if needed
        ),
        ft.Column(
            [ft.Row(sections_buttons, alignment=ft.MainAxisAlignment.CENTER)],
            alignment=ft.MainAxisAlignment.START
        ),
        grid
    )